
module audio_visualizer(

	//////////// CLOCK //////////
	input 		          		ADC_CLK_10,
	input 		          		MAX10_CLK1_50,
	input 		          		MAX10_CLK2_50,

	//////////// SDRAM //////////
	output		    [12:0]		DRAM_ADDR,
	output		     [1:0]		DRAM_BA,
	output		          		DRAM_CAS_N,
	output		          		DRAM_CKE,
	output		          		DRAM_CLK,
	output		          		DRAM_CS_N,
	inout 		    [15:0]		DRAM_DQ,
	output		          		DRAM_LDQM,
	output		          		DRAM_RAS_N,
	output		          		DRAM_UDQM,
	output		          		DRAM_WE_N,

	//////////// SEG7 //////////
	output		     [7:0]		HEX0,
	output		     [7:0]		HEX1,
	output		     [7:0]		HEX2,
	output		     [7:0]		HEX3,
	output		     [7:0]		HEX4,
	output		     [7:0]		HEX5,

	//////////// KEY //////////
	input 		     [1:0]		KEY,

	//////////// LED //////////
	output		     [9:0]		LEDR,

	//////////// SW //////////
	input 		     [9:0]		SW,

	//////////// VGA //////////
	output		     [3:0]		VGA_B,
	output		     [3:0]		VGA_G,
	output		          		VGA_HS,
	output		     [3:0]		VGA_R,
	output		          		VGA_VS,

	//////////// Accelerometer //////////
	output		          		GSENSOR_CS_N,
	input 		     [2:1]		GSENSOR_INT,
	output		          		GSENSOR_SCLK,
	inout 		          		GSENSOR_SDI,
	inout 		          		GSENSOR_SDO,

	//////////// Arduino //////////
	inout 		    [15:0]		ARDUINO_IO,
	inout 		          		ARDUINO_RESET_N,

	//////////// GPIO, GPIO connect to GPIO Default //////////
	inout 		    [35:0]		GPIO
);

	assign HEX0 = 8'hff;
	assign HEX1 = 8'hff;
	assign HEX2 = 8'hff;
	assign HEX3 = 8'hff;
	assign HEX4 = 8'hff;
	assign HEX5 = 8'hff;
	assign LEDR = {GPIO[3:0], 6'b0};
    assign ARDUINO_IO[5] = DRAM_CLK;
	wire rst = ARDUINO_RESET_N;


	video_system video(
		.clk_clk(MAX10_CLK1_50),
		.rst_reset_n(rst),
		.vga_HS(VGA_HS),
		.vga_VS(VGA_VS),
		.vga_R(VGA_R),
		.vga_G(VGA_G),
		.vga_B(VGA_B),
		.sdram_addr(DRAM_ADDR),
		.sdram_ba(DRAM_BA),
		.sdram_cas_n(DRAM_CAS_N),
		.sdram_cke(DRAM_CKE),
		.sdram_cs_n(DRAM_CS_N),
		.sdram_dq(DRAM_DQ),
		.sdram_dqm({DRAM_UDQM, DRAM_LDQM}),
		.sdram_ras_n(DRAM_RAS_N),
		.sdram_we_n(DRAM_WE_N),
		.sdram_clk_clk(DRAM_CLK),
		.spi_sclk_to_the_spislave_inst_for_spichain(GPIO[0]),          //          .sclk_to_the_spislave_inst_for_spichain
		.spi_mosi_to_the_spislave_inst_for_spichain(GPIO[1]),          //       spi.mosi_to_the_spislave_inst_for_spichain
		.spi_miso_to_and_from_the_spislave_inst_for_spichain(GPIO[2]), //          .miso_to_and_from_the_spislave_inst_for_spichain
		.spi_nss_to_the_spislave_inst_for_spichain(GPIO[3])           //          .nss_to_the_spislave_inst_for_spichain
	);

endmodule

